@@ -2,7 +2,7 @@
 
 # py_tools_ds
 #
-# Copyright (C) 2019  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2016-2021  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 #
 # This software was developed within the context of the GeoMultiSens project funded
 # by the German Federal Ministry of Education and Research
@@ -429,7 +429,9 @@ def warp_ndarray(ndarray, in_gt, in_prj=None, out_prj=None, out_dtype=None,
     #    in_ds.SetMetadata(rpc, "RPC")
     #    transformerOptions = ['RPC_DEM=data/warp_52_dem.tif']
 
-    if CPUs is None or CPUs > 1:
+    # use GDALs multiprocessing as long as the current process is not a child process of a multiprocess main thread
+    # - otherwise, gdal.Warp() hangs with GDAL versions from 3.2.1 and above (does not allow sub-multiprocessing)
+    if (CPUs is None or CPUs > 1) and multiprocessing.parent_process() is None:
         gdal.SetConfigOption('GDAL_NUM_THREADS', str(CPUs if CPUs else multiprocessing.cpu_count()))
 
         # gdal.SetConfigOption('GDAL_CACHEMAX', str(800))
